@@ -1,6 +1,8 @@
 import numpy as np
 import re
 
+from numpy.core.fromnumeric import argmax
+
 
 def get_Several_MinMax_Array(np_arr, several):
     """
@@ -25,6 +27,19 @@ def get_Several_MinMax_Array(np_arr, several):
     return index_pos, several_min_or_max
 
 
+def get_non_zero_parts(signal):
+    signal = np.array(signal) != 0
+    assert signal.ndim == 1
+    if np.max(signal) == 0:
+        return [], []
+    temp_signal = np.hstack([0, signal, 0])
+    diff_signal = temp_signal[1:] - temp_signal[:-1]
+    starts = np.nonzero(diff_signal > 0)[0]
+    ends = np.nonzero(diff_signal < 0)[0]
+    assert len(starts) == len(ends)
+    return starts, ends
+
+
 def find_longest_start_end(arr):
     substr = max(re.findall('1+', str(arr)))
     obj = re.search(substr, str(arr))
@@ -125,4 +140,14 @@ def bilinear_by_meshgrid(image, x_grid, y_grid):
     
     res_image = wa*Ia + wb*Ib + wc*Ic + wd*Id
 
-    return res_image
\ No newline at end of file
+    return res_image
+
+
+def get_start_and_end(data):
+    data = np.array(data)
+    assert data.ndim == 1
+    signal = data != 0
+    length = len(signal)
+    start = np.argmax(signal)
+    end = length - np.argmax(signal[::-1]) - 1
+    return start, end
