@@ -2,12 +2,14 @@ import re
 import cv2
 import sys
 import cv2 as cv
+from matplotlib.patches import Polygon
 from mtutils.utils_vvd.box_processing import get_xyxy
 import numpy as np
 import PIL.Image as Image
 
 import matplotlib
 import matplotlib.pyplot as plt
+import math
 
 from .utils import is_number, vvd_round
 from .utils import is_path_obj
@@ -98,6 +100,22 @@ def to_gray_image(img):
         raise RuntimeError(f"unknown data type {type(img)}")
 
 
+def min_max_normalize(image, min=0, max=1, min_p=0, max_p=100):
+    assert 0 <= min_p < max_p <= 100, f"0 <= min_p {min_p} < max_p {max_p}<= 100 should be true." 
+    assert min < max, f"min {min} < max {max} should be true."
+
+    min_value = np.percentile(image, min_p)
+    max_value = np.percentile(image, max_p)
+
+    if max_value == min_value:
+        res_image = image - max_value + min
+    else:
+        assert min_value < max_value
+        clip_image = np.clip(image, min_value, max_value)
+        res_image = (clip_image - min_value) / (max_value - min_value) * (max - min) + min
+    return res_image
+
+
 def median_transfer(image, gray=False, target_median=120):
     if gray:
         image = to_gray_image(image)
@@ -234,7 +252,7 @@ def cv_rgb_bgr_convert(image):
     Returns:
         [image]: [r and b swapped]
     """
-    b, g, r = cv.split(image)
+    b, g, r = cv.split(image.astype('uint8'))
     image = cv.merge([r, g, b])
 
     return image
@@ -250,10 +268,10 @@ def image_show(image, window_name='image show'):
 
 def image_read(image_path, channel=3):
     """
-    读取图像，可包含中文路径
+    读取图像, 可包含中文路径
     Args:
         image_path ([str]): [图像路径]
-        channel (int, optional): [图像通道数，-1为默认，0为灰度]. Defaults to -1.
+        channel (int, optional): [图像通道数, -1为默认, 0为灰度]. Defaults to -1.
     """
     image_path = str(image_path)
     return cv.imdecode(np.fromfile(image_path, dtype=np.uint8), channel)
@@ -277,7 +295,7 @@ def cv_image_show(image, window_name='image show'):
 
 def extend_image_channel(input_image):
     '''
-    cv显示三通道图像，本函数将原始图像扩展到三通道
+    cv显示三通道图像, 本函数将原始图像扩展到三通道
     '''
     image = input_image.copy()
 
@@ -383,7 +401,7 @@ def image_show_from_path(file_path):
         plt_image_show(image)
 
 
-def plt_image_show(*image, window_name='image show', array_res=False, full_screen=True, cmap=None, position=[30, 30], share_xy=False, axis_off=False):
+def plt_image_show(*image, window_name='', array_res=False, full_screen=True, cmap=None, position=[30, 30], share_xy=False, axis_off=False):
     '''
     更加鲁棒地显示图像包括二维图像,第三维度为1的图像
     '''
@@ -403,7 +421,7 @@ def plt_image_show(*image, window_name='image show', array_res=False, full_scree
 
     backend = matplotlib.get_backend()
 
-    plt.subplots_adjust(top=0.93, bottom=0.05, left=0.05, right=0.95, hspace=0.05, wspace=0.05)
+    plt.subplots_adjust(top=0.95, bottom=0.05, left=0.05, right=0.95, hspace=0.15, wspace=0.05)
 
     for index, image_item in enumerate(image_list):
         x_value = None
@@ -562,9 +580,9 @@ def crop_data_around_boxes(image, crop_box, cut_box_back=False):
 
 def zero_padding(in_array, padding_size_1, padding_size_2, padding_size_3=None, padding_size_4=None):
     """
-    四周补零，以此避免边界判断(仅用于三通道图像)
+    四周补零, 以此避免边界判断(仅用于三通道图像)
 
-    输入：
+    输入: 
     :in_array: 输入矩阵 np.array (rows, cols, 3)
 
     (padding_size_3-4 为 None 时)
@@ -577,8 +595,8 @@ def zero_padding(in_array, padding_size_1, padding_size_2, padding_size_3=None,
     :padding_size_3:  左补零列数
     :padding_size_4:  右补零列数
 
-    输出：
-    :padded_array: 补零后的图像（新建矩阵，不修改原始输入）
+    输出: 
+    :padded_array: 补零后的图像（新建矩阵, 不修改原始输入）
     """
 
     assert np.ndim(in_array) == 3 or np.ndim(in_array) == 2
@@ -732,6 +750,27 @@ def local_normalization(image, k_size=5):
     return res_image
 
 
+def rectangle2polygon(rec):
+    ((x1, y1), (x2, y2)) = rec
+    polygon = xyxy2polygon(x1, y1, x2, y2)
+    return polygon
+
+
+def bbox2polygon(bbox):
+    x1, y1, x2, y2 = bbox
+    polygon = xyxy2polygon(x1, y1, x2, y2)
+    return polygon
+
+
+def xyxy2polygon(x1, y1, x2, y2):
+    points = []
+    points.append([x1, y1])
+    points.append([x1, y2])
+    points.append([x2, y2])
+    points.append([x2, y1])
+    return points
+
+
 def get_polygons_from_mask(mask):
     """ get polygons for all isolated areas on fg-mask
         return something like: [[x1,y1], [x2,y2], [x3,y3], ...]
